==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/hco30.h <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
&ifdef KERNEL
/*!*****************************************************************************
*
* module:       hco30.h
*
* ------------------------------------------------------------------------------
*
* responsible:  T.Anhaus
*
* lastChanged:  1999-07-20
*
* purpose:      Common Base of SQL and OMS
*
* generatedBy: 
*
* ------------------------------------------------------------------------------
*
* Copyright by SAP AG, 1999
*
********************************************************************************/
&else
/*******************************************************************************
*
* Copyright by SAP AG, 1999
*
********************************************************************************/
&endif
&ifdef KERNEL
#ifndef HCO30_H
#define HCO30_H


#include "ggg92.h"
#include "gco00.h"
#include "ilivecachesink.h" /* no check */
#include "gco01.h"
#include "hco31-k.h"
&else
#ifndef _LIVECACHEBASE
#define _LIVECACHEBASE
#include "livecachetypes.h"    /* no check */
#include "livecachedbperror.h" /* no check */
&endif

typedef void  (*DbpPROC)();

#if defined(WIN32) 
typedef HANDLE DbpHandle;
#else
typedef void* DbpHandle;
#endif

/*!
  class :  DbpBase

  description: Base Class for SQL-Handle and OMS-Handle
  
  note       : changes must be maintenanced in the corresponding file for the user side (hco01.h) 
*/

class AFX_EXT_CLASS DbpBase {
public :
  DbpBase();
  DbpBase(IUnknown * pSink);
/*!
  Function:     dbpDebugBreak
  description:  causes a break point, if running in the livecache proxy (Win NT only)

  arguments:
    none
    
  return value: none
*/
  void           dbpDebugBreak();
/*!
  Function:     dbpDropMessageFile
  description:  drops a message file
    
    This tries to drop a named MessageFile. If the file does not exist or is still open,
    it will not be dropped and an error is thrown instead.

  arguments:
    fn [in] The file name of the file to be dropped
    
  return value: none
*/
  void           dbpDropMessageFile(const char* fn);
/*!
  Function:     dbpExistsFile
  description:  Checks for existence of file or directory
    
    Called to test for existence of file or directory. 
    Sets doesExist to true if file or directory exists, false otherwise or if error occured.
    If doesExist is false isDirectory is always set to false.

  arguments:
    fn           [in]  The file/directory name
    doesExist    [out] Set to true if file or directory was found, false if not.
    isDirectory  [out] Set to true to indicate directory was found, false if not.
   
  return value: none
*/
  void           dbpExistsFile(const char* fn, bool& doesExist, bool& IsDirectory);
/*!
  Function: dbpFreeLibrary 

  description: unloads a shared library

  arguments:
     hd                 [IN]  - Handle to the shared library. 
  
  return value : none 
 */
  void dbpFreeLibrary (DbpHandle hd);
/*!
  Function:     dbpGetDbrootSapPath
  description:  gets the DBROOT dependent "sap" path ( libraries, shared libraries... )
    
  arguments:
    path [out]  the required path 
    bufSize[in] the size of the path buffer provided by the caller
    
  return value: none
 */
  void           dbpGetDbrootSapPath(char* path, int bufSize);
/*!
  Function:     dbpGetProcAddress
  description: determines the address of a funtcion from a shared library

  arguments :
    hd [in]       Handle to the shared library provided by dbpLoadLibrary. 
    pProcName[in] Name of the function 

  return value: a pointer to the function
 */
  DbpPROC dbpGetProcAddress(DbpHandle hd, const char *pProcName);
/*!
  Function:     dbpGetWorkingDirectory
  description:  Get path to directory where message files are stored
    
    This returns the path to the directory that is used for all relativ specified message files.
    It should be identical to the WorkingDirectory of the database.
    
  arguments:
    path [out]  The path to the root of all relativ specified message files
    bufSize[in] the size of the path buffer provided by the caller
    
  return value: none
 */
  void           dbpGetWorkingDirectory(char* path, int bufSize);
/*!
  Function: dbpLoadLibrary 

  description: loads a shared library

  arguments:
     path[in]        The name of the library to be loaded. The name can 
                     include the path but it should no include the fileextension. 
     loadGobal[in]   true  : load with 'global' scope of symbol-resolution
                     false : load with 'local' scope of symbol-resolution
  
   return - handle for the loaded library.
 */
  DbpHandle      dbpLoadLibrary(const char* path, bool loadGlobal);
/*!
  Function:     dbpOpError
  description:  writes an error message into the kernel diag file

  arguments:
    fmt [in] :  a format specification (like printf).

  return value : none
 */
  void           dbpOpError( const char*fmt, ... );
  void           dbpOpErrorVarg( const char*fmt,va_list args );
/*!
  Function:     dbpOpMsg
  description:  writes a message into the kernel diag file

  arguments:
    fmt [in] :  a format specification (like printf).

  return value : none
 */
  void           dbpOpMsg( const char*fmt, ... );
  void           dbpOpMsgVarg( const char*fmt, va_list args );
/*!
  Function:     dbpTrace
  description:  writes a message into the kernel trace file

  arguments:
    fmt [in] :  a format specification (like printf).

  return value : none
*/
  void           dbpTrace( const char*fmt, ... );
  void           dbpTraceVarg( const char*fmt, va_list args );
/*!
  Function:     dbpOpenMessageFile
  description:  Opens a message file
    if doAppend is true and the file already exists it is opened but writing takes place at end of file.
    MaxFileSize is ignored in such a case.
    if doAppend is false or the file does not exist, a file is created. If file already exists and 
    is not still opened it is overwritten! So be carefull, choosing the filename.

    A second open to the same file, simply increases a reference count. 
    MaxFileSize is ignored in such a case.

    For each open, a close must be issued.
    
  arguments:
    Filename [in] The file name
    fileSize [in] The maximum size of the file. If 0 the file size is ignored. fileSize has
                  no meaning, if the file already exists and is not overwritten.
                  If not 0 writing restarts at beginning of file after MaxFileSize was reached.
    doAppend[in]  True : if the file already exist it is opened but writing takes place at end of file.
                  False : if the file already exists, it is overwritten

  return value: The index of the message file (NOT a file handle!!!)
 */
  OmsTypeInt4    dbpOpenMessageFile (const char* fn, unsigned long fileSize, bool doAppend);
/*!
  Function:     dbpWriteMessageFile
  description:  Write a variable length null terminated string into a message file
    
    This expects a 0 terminated 'C String' as input. The message written is not flushed
    immediatly, but stored in internal buffers. Flushing takes place on dbpCloseMessageFile.
    The length of the message is restricted to 255 bytes.
        
    NOTE - If length of message exceeds MaxFileSize, only the last 'piece' of the message will
    be visible.

  arguments:
    fileHandle [in] The file index returned by dbpOpenMessageFile
    msg        [in] The message to be written.
    
  return value: none
 */
  void           dbpWriteMessageFile(OmsTypeInt4 fileHandle, const char*fmt, ... );
  void           dbpWriteMessageFileVarg(OmsTypeInt4 fileHandle, const char*fmt, va_list args );
/*!
  Function:     dbpCloseMessageFile
  description:  closes a message file
    
    This flushes the content of the buffers and allows the index to be used again by a 
    different dbpOpenMessageFile call.

    If file was opened more than once, the reference count is decreased but the file
    is kept open.

    But always the file is implicitly synchronized as if dbpSyncMessageFile() was called.
  
  arguments:
    fileHandle [in] : the file index returned by dbpOpenMessageFile
    fmt [in]        : a format specification (like printf). 
    ...             : paramaters (like printf)
  return value: none
 */
  void           dbpCloseMessageFile(OmsTypeInt4 fileHandle);
/*
  Function:     dbpSyncMessageFile
  description:  flushes buffered messages into a message file
    
    This flushes the content of the buffers without closing the file. Not really needed for
    small files, since flushing takes place automatically before dbpCloseMessageFile.

  NOTE: Using this after each write, will reduce performance of the database dramatically...

  arguments:
    fileHandle[in] The file index returned by dbpOpenMessageFile
    
  return value: none
 */
  void           dbpSyncMessageFile (OmsTypeInt4 fileHandle);
/*
  Function:     dbpSyncMessageFile
  description:  flushes buffered messages into a message file
    
    This flushes the content of the buffers without closing the file. Not really needed for
    small files, since flushing takes place automatically before dbpCloseMessageFile.

  NOTE: Using this after each write, will reduce performance of the database dramatically...

  arguments:
    fn [in]  The name of the message file as specified in dbpOpenMessageFile.
    
  return value: none
 */
  void           dbpSyncMessageFile (const char* fn);
protected :
&ifdef KERNEL
  void           dbpAdviseLcSink (IliveCacheSink* pSink);
&endif
private :
&ifdef KERNEL
  IliveCacheSink* m_lcSink;
&else
  IUnknown* m_lcSink;
&endif
};

/*! endclass: DbpBase */

&ifdef KERNEL
#if defined(WIN32)
inline void DbpBase::dbpDebugBreak() {
  if (m_lcSink->IsDebugEnvironment())
    DebugBreak();
};
#endif
&endif

#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/hco30.h <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
&ifdef KERNEL
/*!*****************************************************************************

  module:       hco30.h

  ------------------------------------------------------------------------------

  responsible:  ThomasA

  lastChanged:  1999-07-20

  purpose:      Common Base of SQL and OMS

  generatedBy:

  ------------------------------------------------------------------------------

  Copyright by SAP AG, 1999

********************************************************************************/
&else
/*******************************************************************************
*
* Copyright by SAP AG, 1999
*
********************************************************************************/
&endif
&ifdef KERNEL
#ifndef HCO30_H
#define HCO30_H


#include "ggg92.h"
#include "gco00.h"
#include "ilivecachesink.h" /* no check */
#include "gco01.h"
#include "hco31-k.h"
&else
#ifndef _LIVECACHEBASE
#define _LIVECACHEBASE
#include "livecachetypes.h"    /* no check */
#include "livecachedbperror.h" /* no check */
&endif

typedef void  (*DbpPROC)();

#if defined(WIN32)
typedef HANDLE DbpHandle;
#else
typedef void* DbpHandle;
#endif

/*!
  class :  DbpBase

  description: Base Class for SQL-Handle and OMS-Handle

  note       : changes must be maintenanced in the corresponding file for the user side (hco01.h)
*/

class AFX_EXT_CLASS DbpBase {
public :
  DbpBase();
  DbpBase(IUnknown * pSink);
/*!
  Function:     dbpDebugBreak
  description:  causes a break point, if running in the livecache proxy (Win NT only)

  arguments:
    none

  return value: none
*/
  void           dbpDebugBreak();
/*!
  Function:     dbpDropMessageFile
  description:  drops a message file

    This tries to drop a named MessageFile. If the file does not exist or is still open,
    it will not be dropped and an error is thrown instead.

  arguments:
    fn [in] The file name of the file to be dropped

  return value: none
*/
  void           dbpDropMessageFile(const char* fn);
/*!
  Function:     dbpExistsFile
  description:  Checks for existence of file or directory

    Called to test for existence of file or directory.
    Sets doesExist to true if file or directory exists, false otherwise or if error occured.
    If doesExist is false isDirectory is always set to false.

  arguments:
    fn           [in]  The file/directory name
    doesExist    [out] Set to true if file or directory was found, false if not.
    isDirectory  [out] Set to true to indicate directory was found, false if not.

  return value: none
*/
  void           dbpExistsFile(const char* fn, bool& doesExist, bool& IsDirectory);
/*!
  Function: dbpFreeLibrary

  description: unloads a shared library

  arguments:
     hd                 [IN]  - Handle to the shared library.

  return value : none
 */
  void dbpFreeLibrary (DbpHandle hd);
/*!
  Function:     dbpGetDbrootSapPath
  description:  gets the DBROOT dependent "sap" path ( libraries, shared libraries... )

  arguments:
    path [out]  the required path
    bufSize[in] the size of the path buffer provided by the caller

  return value: none
 */
  void           dbpGetDbrootSapPath(char* path, int bufSize);
/*!
  Function:     dbpGetProcAddress
  description: determines the address of a funtcion from a shared library

  arguments :
    hd [in]       Handle to the shared library provided by dbpLoadLibrary.
    pProcName[in] Name of the function

  return value: a pointer to the function
 */
  DbpPROC dbpGetProcAddress(DbpHandle hd, const char *pProcName);
/*!
  Function:     dbpGetWorkingDirectory
  description:  Get path to directory where message files are stored

    This returns the path to the directory that is used for all relativ specified message files.
    It should be identical to the WorkingDirectory of the database.

  arguments:
    path [out]  The path to the root of all relativ specified message files
    bufSize[in] the size of the path buffer provided by the caller

  return value: none
 */
  void           dbpGetWorkingDirectory(char* path, int bufSize);
/*!
  Function: dbpLoadLibrary

  description: loads a shared library

  arguments:
     path[in]        The name of the library to be loaded. The name can
                     include the path but it should no include the fileextension.
     loadGobal[in]   true  : load with 'global' scope of symbol-resolution
                     false : load with 'local' scope of symbol-resolution

   return - handle for the loaded library.
 */
  DbpHandle      dbpLoadLibrary(const char* path, bool loadGlobal);
/*!
  Function:     dbpOpError
  description:  writes an error message into the kernel diag file

  arguments:
    fmt [in] :  a format specification (like printf).

  return value : none
 */
  void           dbpOpError( const char*fmt, ... );
  void           dbpOpErrorVarg( const char*fmt,va_list args );
/*!
  Function:     dbpOpMsg
  description:  writes a message into the kernel diag file

  arguments:
    fmt [in] :  a format specification (like printf).

  return value : none
 */
  void           dbpOpMsg( const char*fmt, ... );
  void           dbpOpMsgVarg( const char*fmt, va_list args );
/*!
  Function:     dbpTrace
  description:  writes a message into the kernel trace file

  arguments:
    fmt [in] :  a format specification (like printf).

  return value : none
*/
  void           dbpTrace( const char*fmt, ... );
  void           dbpTraceVarg( const char*fmt, va_list args );
/*!
  Function:     dbpOpenMessageFile
  description:  Opens a message file
    if doAppend is true and the file already exists it is opened but writing takes place at end of file.
    MaxFileSize is ignored in such a case.
    if doAppend is false or the file does not exist, a file is created. If file already exists and
    is not still opened it is overwritten! So be carefull, choosing the filename.

    A second open to the same file, simply increases a reference count.
    MaxFileSize is ignored in such a case.

    For each open, a close must be issued.

  arguments:
    Filename [in] The file name
    fileSize [in] The maximum size of the file. If 0 the file size is ignored. fileSize has
                  no meaning, if the file already exists and is not overwritten.
                  If not 0 writing restarts at beginning of file after MaxFileSize was reached.
    doAppend[in]  True : if the file already exist it is opened but writing takes place at end of file.
                  False : if the file already exists, it is overwritten

  return value: The index of the message file (NOT a file handle!!!)
 */
  OmsTypeInt4    dbpOpenMessageFile (const char* fn, unsigned long fileSize, bool doAppend);
/*!
  Function:     dbpWriteMessageFile
  description:  Write a variable length null terminated string into a message file

    This expects a 0 terminated 'C String' as input. The message written is not flushed
    immediatly, but stored in internal buffers. Flushing takes place on dbpCloseMessageFile.
    The length of the message is restricted to 255 bytes.

    NOTE - If length of message exceeds MaxFileSize, only the last 'piece' of the message will
    be visible.

  arguments:
    fileHandle [in] The file index returned by dbpOpenMessageFile
    msg        [in] The message to be written.

  return value: none
 */
  void           dbpWriteMessageFile(OmsTypeInt4 fileHandle, const char*fmt, ... );
  void           dbpWriteMessageFileVarg(OmsTypeInt4 fileHandle, const char*fmt, va_list args );
/*!
  Function:     dbpCloseMessageFile
  description:  closes a message file

    This flushes the content of the buffers and allows the index to be used again by a
    different dbpOpenMessageFile call.

    If file was opened more than once, the reference count is decreased but the file
    is kept open.

    But always the file is implicitly synchronized as if dbpSyncMessageFile() was called.

  arguments:
    fileHandle [in] : the file index returned by dbpOpenMessageFile
    fmt [in]        : a format specification (like printf).
    ...             : paramaters (like printf)
  return value: none
 */
  void           dbpCloseMessageFile(OmsTypeInt4 fileHandle);
/*
  Function:     dbpSyncMessageFile
  description:  flushes buffered messages into a message file

    This flushes the content of the buffers without closing the file. Not really needed for
    small files, since flushing takes place automatically before dbpCloseMessageFile.

  NOTE: Using this after each write, will reduce performance of the database dramatically...

  arguments:
    fileHandle[in] The file index returned by dbpOpenMessageFile

  return value: none
 */
  void           dbpSyncMessageFile (OmsTypeInt4 fileHandle);
/*
  Function:     dbpSyncMessageFile
  description:  flushes buffered messages into a message file

    This flushes the content of the buffers without closing the file. Not really needed for
    small files, since flushing takes place automatically before dbpCloseMessageFile.

  NOTE: Using this after each write, will reduce performance of the database dramatically...

  arguments:
    fn [in]  The name of the message file as specified in dbpOpenMessageFile.

  return value: none
 */
  void           dbpSyncMessageFile (const char* fn);
protected :
&ifdef KERNEL
  void           dbpAdviseLcSink (IliveCacheSink* pSink);
&endif
private :
&ifdef KERNEL
  IliveCacheSink* m_lcSink;
&else
  IUnknown* m_lcSink;
&endif
};

/*! endclass: DbpBase */

&ifdef KERNEL
#if defined(WIN32)
inline void DbpBase::dbpDebugBreak() {
  if (m_lcSink->IsDebugEnvironment())
    DebugBreak();
};
#endif
&endif

#endif
